## cdist-type__apt_key(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__apt_key - manage the list of keys used by apt

## 2. DESCRIPTION

Manages the list of keys used by apt to authenticate packages.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

state
  present or absent. Defaults to present
keyid
  the id of the key to add. Defaults to __object_id
keyserver
  the keyserver from which to fetch the key. If omitted the default set in ./parameter/default/keyserver is used.

## 5. EXAMPLES

    # Add Ubuntu Archive Automatic Signing Key
    __apt_key 437D05B5
    # Same thing
    __apt_key 437D05B5 --state present
    # Get rid of it
    __apt_key 437D05B5 --state absent

    # same thing with human readable name and explicit keyid
    __apt_key UbuntuArchiveKey --keyid 437D05B5

    # same thing with other keyserver
    __apt_key UbuntuArchiveKey --keyid 437D05B5 --keyserver keyserver.ubuntu.com

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011-2014 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).